<?php

/**
 * Written by Kevin Israel. Released to the public domain.
 */

function readSvnLog( $filename ) {
	$arr = array();
	$doc = simplexml_load_file( $filename );

	foreach ( $doc->logentry as $logentry ) {
		if ( !$logentry->date ) {
			continue;
		}
		$arr[] = array(
			'id' => (int) $logentry['revision'],
			'user' => (string) $logentry->author,
			'timestamp' => DateTime::createFromFormat( 'Y-m-d\TH:i:s.uO', $logentry->date )->getTimestamp(),
		);
	}

	return array_reverse( $arr );
}

function readGitLog( $filename ) {
	$arr = array();
	$handle = fopen( $filename, 'r' );

	while ( true ) {
		$line = fgets( $handle );
		if ( $line === false ) {
			break;
		}

		$line = rtrim( $line, "\n" );
		if ( $line === '' ) {
			break;
		}

		$fields = explode( "\t", $line );
		$arr[] = array(
			'id' => $fields[0],
			'user' => $fields[1],
			'timestamp' => (int) $fields[2],
		);
	}
	fclose( $handle );
	return $arr;
}

function readUserAliases( $path ) {
	$iter = new DirectoryIterator( $path );
	$arr = array();
	while ( $iter->valid() ) {
		if ( !$iter->isFile() ) {
			$iter->next();
			continue;
		}

		$contents = file_get_contents( $iter->getPathname() );
		if ( !preg_match( '/^aliases:(.*)/m', $contents, $matches ) ) {
			$iter->next();
			continue;
		}

		$aliases = array_map( 'trim', explode( ',', $matches[1] ) );
		foreach ( $aliases as $alias ) {
			if ( $alias !== '' ) {
				$arr[$alias] = $iter->getFilename();
			}
		}

	    $iter->next();
	}
	return $arr;
}

function rearrangeLog( $log ) {
	$arr = array();
	foreach ( $log as $entry ) {
		$arr[$entry['user'] . "\0" . $entry['timestamp']][] = $entry['id'];
	}
	return $arr;
}

function formatGitData( $data ) {
	$len = strlen( $data );
	return "data $len\n$data\n";
}

